smaz

package module
v0.0.0-...-49b3bd4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func UnZip

func UnZip(b []byte) ([]byte, error)

smaz.UnZip Decompresses with SMAZ from a utf8 []byte

this method will try to decode from base64, or will skip that step if it fails (this means you do not have to know if you encoded your string to base64 on compression)

func Zip

func Zip(b []byte, encode ...bool) []byte

smaz.Zip Compresses with SMAZ from a utf8 []byte

@encode: true = encode to base64

Types

This section is empty.

Jump to